@@ -1,3 +1,4 @@
+import pytz
 import attr
 import binascii
 import hashlib
@@ -58,6 +59,22 @@ def boomerang_stream(stream: TextIOWrapper) -> TextIOWrapper:
     stream.seek(current_offset)
 
 
+def convert_filetime(dw_low_date_time, dw_high_date_time):
+    """
+    """
+    if dw_high_date_time is None or dw_low_date_time is None:
+        return None
+    try:
+        date = dt.datetime(1601, 1, 1, 0, 0, 0)
+        temp_time = dw_high_date_time
+        temp_time <<= 32
+        temp_time |= dw_low_date_time
+        date = pytz.utc.localize(date + dt.timedelta(microseconds=temp_time / 10))
+        return date.isoformat()
+    except OverflowError:
+        return None
+
+
 def convert_wintime(wintime: int, as_json=False) -> dt.datetime:
     """
     Get an integer containing a FILETIME date
@@ -70,7 +87,7 @@ def convert_wintime(wintime: int, as_json=False) -> dt.datetime:
     try:
         date = dt.datetime(1601, 1, 1, tzinfo=pytz.utc) + dt.timedelta(microseconds=us)
     except OverflowError:
-        # If date is too big, it is probably corrupted' let's return the smalles possible windows timestamp.
+        # If date is too big, it is probably corrupted' let's return the smallest possible windows timestamp.
         date = dt.datetime(1601, 1, 1, tzinfo=pytz.utc)
     return date.isoformat() if as_json else date
 
@@ -125,10 +142,10 @@ def identify_hive_type(name: str) -> str:
 
 def try_decode_binary(data, as_json=False, max_len=MAX_LEN):
     try:
-        value = data.decode('utf-16-le').rstrip('\x00')
+        value = data.decode('utf-16-le').rstrip('\x00')[:max_len]
     except UnicodeDecodeError:
         try:
-            value = data.decode().rstrip('\x00')
+            value = data.decode().rstrip('\x00')[:max_len]
         except:
             value = binascii.b2a_hex(data).decode()[:max_len] if as_json else data
     return value
